@@ -1,8 +1,8 @@
 from copy import deepcopy
-from typing import Any, Optional, Type, Union
+from typing import Any, Type
 
-from fastapi import Depends
-from pydantic import BaseModel, Extra, create_model, fields, validator
+from fastapi import Depends, HTTPException, status
+from pydantic import BaseModel, Extra, ValidationError, create_model, fields, validator
 from pydantic.fields import FieldInfo
 
 
@@ -18,7 +18,7 @@ class BaseFilterModel(BaseModel, extra=Extra.forbid):
         ...
 
 
-def nested_filter(prefix, Filter):
+def nested_filter(prefix: str, Filter: Type[BaseFilterModel]):
     """Allow re-using existing filter under a prefix.
 
     Example:
@@ -27,12 +27,13 @@ def nested_filter(prefix, Filter):
         from fastapi_filter.filter import FilterDepends
 
         class NumberFilter(BaseModel):
-            count: Optional[int]
+            count: int | None
 
         class MainFilter(BaseModel):
             name: str
-            number_filter: Optional[Filter] = FilterDepends(nested_filter("number_filter", Filter))
+            number_filter: Filter | None = FilterDepends(nested_filter("number_filter", Filter))
         ```
+
     As a result, you'll get the following filters:
         * name
         * number_filter__count
@@ -59,7 +60,7 @@ def nested_filter(prefix, Filter):
         * counter (*NOT* number_filter__counter)
     """
 
-    class NestedFilter(Filter):
+    class NestedFilter(Filter):  # type: ignore[misc, valid-type]
         class Config:
             extra = Extra.forbid
 
@@ -71,14 +72,14 @@ def nested_filter(prefix, Filter):
 
 
 def _list_to_str_fields(Filter: Type[BaseFilterModel]):
-    ret: dict[str, tuple[Union[object, Type], Optional[FieldInfo]]] = {}
+    ret: dict[str, tuple[object | Type, FieldInfo | None]] = {}
     for f in Filter.__fields__.values():
         field_info = deepcopy(f.field_info)
         if f.shape == fields.SHAPE_LIST:
-            ret[f.name] = (Optional[str], field_info)
+            ret[f.name] = (str | None, field_info)
         else:
             field_type = Filter.__annotations__.get(f.name, f.outer_type_)
-            ret[f.name] = (Optional[field_type], field_info)
+            ret[f.name] = (field_type | None, field_info)
 
     return ret
 
@@ -99,7 +100,10 @@ def FilterDepends(Filter: Type[BaseFilterModel], *, use_cache: bool = True) -> A
 
     class FilterWrapper(GeneratedFilter):  # type: ignore[misc,valid-type]
         def filter(self, *args, **kwargs):
-            original_filter = Filter(**self.dict())
+            try:
+                original_filter = Filter(**self.dict())
+            except ValidationError as e:
+                raise HTTPException(status_code=status.HTTP_422_UNPROCESSABLE_ENTITY, detail=str(e))
             return original_filter.filter(*args, **kwargs)
 
     return Depends(FilterWrapper)
